Class: Fastlane::Helper::QueueHelper
- Inherits:
-
Object
- Object
- Fastlane::Helper::QueueHelper
- Defined in:
- lib/fastlane/plugin/queue/helper/queue_helper.rb
Class Method Summary collapse
-
.show_message ⇒ Object
class methods that you define here become available in your action as
Helper::QueueHelper.your_method.
Class Method Details
.show_message ⇒ Object
class methods that you define here become available in your action as Helper::QueueHelper.your_method
7 8 9 |
# File 'lib/fastlane/plugin/queue/helper/queue_helper.rb', line 7 def self. UI.("Hello from the queue plugin helper!") end |